/* -*- Mode: C; c-file-style: "stroustrup"; -*- */
#include "xycontrolpoint.h"

static gpointer parent_class = NULL;

static void xy_control_point_init            (XYControlPoint      *instance,
					     gpointer            g_class);
static void xy_control_point_class_base_init (XYControlPointClass *class);
static void xy_control_point_class_init      (XYControlPointClass *class,
					     gpointer            data);
static void xy_control_point_draw            (NxpCanvasOverlay   *self,
					     GdkDrawable        *drawable,
					     GdkGC              *gc,
					     guint               t);


static GTypeInfo typeinfo = 
{
    /* interface types, classed types, instantiated types */
    sizeof(XYControlPointClass), 

    (GBaseInitFunc)xy_control_point_class_base_init, 
    NULL, // GBaseFinalizeFunc      base_finalize;

    /* classed types, instantiated types */
    (GClassInitFunc)xy_control_point_class_init, 
    NULL, // GClassFinalizeFunc     class_finalize;
    NULL, // gconstpointer          class_data;

    /* instantiated types */
    sizeof(XYControlPoint),		//guint16                instance_size;
    0,					//guint16                n_preallocs;
    (GInstanceInitFunc)xy_control_point_init, //GInstanceInitFunc      instance_init;

    /* value handling */
    NULL,				//const GTypeValueTable	*value_table;
};


GType xy_control_point_get_type(void)
{
    static GType type = 0;
    if (!type) 
    {
	type = g_type_register_static(NXP_TYPE_CANVAS_OVERLAY, "XYControlPoint",
				      &typeinfo, 0);
    }
    return type;
}


static void xy_control_point_init(XYControlPoint *self, gpointer g_class)
{
    NxpCanvasOverlay *overlay = NXP_CANVAS_OVERLAY(self);
    overlay->bbox.x = 0;
    overlay->bbox.y = 0;
    overlay->bbox.width = 0;
    overlay->bbox.height = 0;
}


static void xy_control_point_class_base_init(XYControlPointClass *class)
{
    /* empty */
}


static void xy_control_point_class_init(XYControlPointClass *class, gpointer data)
{
    /* GObjectClass *object_class = G_OBJECT_CLASS(class); */
    NxpCanvasOverlayClass *overlay_class = NXP_CANVAS_OVERLAY_CLASS(class);

    parent_class = g_type_class_peek_parent (class);
    overlay_class->draw = xy_control_point_draw;
}


static void xy_control_point_draw(NxpCanvasOverlay *overlay, GdkDrawable *drawable,
                                  GdkGC *gc, guint t)
{
    XYControlPoint *self = XY_CONTROL_POINT(overlay);
    g_return_if_fail(self);
    g_return_if_fail(XY_IS_CONTROL_POINT(self));
    gdk_draw_rectangle(drawable, gc, TRUE, overlay->bbox.x, overlay->bbox.y,
		       overlay->bbox.width, overlay->bbox.height);
}

NxpCanvasOverlay* xy_control_point_new(gint x, gint y, gint size)
{
    GTypeInstance *instance;
    XYControlPoint *self;
    NxpCanvasOverlay *overlay;

    instance = g_type_create_instance(xy_control_point_get_type());
    self = XY_CONTROL_POINT(instance);
    overlay = NXP_CANVAS_OVERLAY(instance);
    overlay->bbox.x = x - size/2;
    overlay->bbox.y = y - size/2;
    overlay->bbox.width = size;
    overlay->bbox.height = size;
    self->x = x;
    self->y = y;
    return NXP_CANVAS_OVERLAY(self);
}

